@@ -17,7 +17,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139,
  * USA. See the COPYING file in this directory.
  *
- * Version: 2.3 -  Jan 2006
+ * Version: 2.4 -  Oct 2006
  */
 
 /*
@@ -419,17 +419,18 @@ void searchCB (Widget w, XtPointer cdata, XtPointer cbs)
 void aboutDiag ()
 {
    static Widget diag = NULL;
+   Widget pb;
    XmString msg_xs;
    char msg_str[] =
       "twlog \251 1997 was written by\nTed Williams - WA\330EIR";
 
-   msg_xs = XmStringCreateLocalized (msg_str);
+   msg_xs = XmStringCreateLtoR (msg_str, XmSTRING_DEFAULT_CHARSET);
    if (diag == NULL)
    {
       diag =
          XmCreateInformationDialog (logSH, "aboutDiag", (ArgList) NULL, 0);
       XtVaSetValues (XtParent (diag),
-         XmNtitle, "ABOUT TW LOG",
+         XmNtitle, "ABOUT TWLOG",
          NULL);
 
       XtVaSetValues (diag,
@@ -440,6 +441,10 @@ void aboutDiag ()
 
       XtUnmanageChild (XmMessageBoxGetChild (diag, XmDIALOG_CANCEL_BUTTON));
       XtUnmanageChild (XmMessageBoxGetChild (diag, XmDIALOG_HELP_BUTTON));
+      XtUnmanageChild (XmMessageBoxGetChild (diag, XmDIALOG_OK_BUTTON));
+
+      pb = XtVaCreateManagedWidget ("OK", xmPushButtonWidgetClass, diag,
+         NULL);
    }
    XtManageChild (diag);
 }
@@ -463,7 +468,7 @@ void numberRows (Widget mw)
          XbaeMatrixSetCell (mw, i - 1, 0, num);
       }
    }
-   else                         /*REVERSE */
+   else                         /* REVERSE */
    {
       //j = 1;
       for (i = 1; i <= rows; i++)
@@ -577,8 +582,10 @@ void build_convDiag (void)
       {
 	 XmStringFree (xs[j]);
       }
+//TJW
+//XtVaCreateManagedWidget ("OK", xmPushButtonWidgetClass, convDiag, NULL);
 
-      form4 = XtVaCreateWidget ("form4", xmFormWidgetClass, convDiag,
+      form4 = XtVaCreateWidget ("convForm", xmFormWidgetClass, convDiag,
          NULL);
 
       topLabel = XtVaCreateManagedWidget ("Convert Log Format",
@@ -601,7 +608,7 @@ void build_convDiag (void)
          NULL);
 
       strcpy (path, dirpath);
-      strcat (path, "adif.log");      /* default if To twlog */
+      strcat (path, "/adif.log");      /* default if To twlog */
       wids[0] = XtVaCreateManagedWidget ("inTextF", xmTextFieldWidgetClass,
          form4,
          XmNcolumns, 30,
@@ -708,14 +715,13 @@ void build_convDiag (void)
 
       XtAddCallback (inBrowsePB, XmNactivateCallback, browserCB, wids[0]);
       XtAddCallback (outBrowsePB, XmNactivateCallback, browserCB, wids[1]);
-
+//TJW change convDiag to new pb's
       XtAddCallback (convDiag, XmNokCallback, convCB, wids);
       XtAddCallback (convDiag, XmNcancelCallback, convCB, wids);
    }
    XtManageChild (convDiag);
 }
 
-
 /*
  * browserCB - Creates and pops up the fsb for input or output fsb.
  * Client data is the wid for the coresponding text field with 
@@ -727,10 +733,11 @@ void browserCB (Widget w, XtPointer cdata, XtPointer cbs)
    Widget wid = (Widget)cdata;
    char dirStr[200] = "\0";
    XmString xs;
-      strcpy (dirStr, getenv ("HOME"));       /* build the dir string */
-      strcat (dirStr, LOGDIR);
-      strcat (dirStr, LOGFILE);
-      xs = XmStringCreateLocalized (dirStr);  /* build xs for fsb dir */
+
+   strcpy (dirStr, getenv ("HOME"));       /* build the dir string */
+   strcat (dirStr, LOGDIR);
+   strcat (dirStr, LOGFILE);
+   xs = XmStringCreateLocalized (dirStr);  /* build xs for fsb dir */
 
    /* create fsb for input file */
    fsb1 = XmCreateFileSelectionDialog (w, "fsb1", NULL, 0);
@@ -944,7 +951,7 @@ void errorDiag (Widget w, char * emess, int flag)
    }
    XtUnmanageChild (XmMessageBoxGetChild(errDiag, XmDIALOG_HELP_BUTTON));
 
-   /* Only the File Exists diag needs addition functionality for OK CB
+   /* Only the File Exists diag needs additional functionality for OK CB
     * so add this callback if there is a Cancel button, since only the
     * File Exists diag has one
     */
