@@ -17,12 +17,10 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139,
  * USA. See the COPYING file in this directory.
  *
- * Version: 2.3 -  Jan 2006
+ * Version: 2.4 -  Oct 2006
  */
 
-#ifndef TWLOG_H_INCLUDED
 #include "twlog.h"
-#endif
 
 /*
  * build_widgets Function
@@ -423,7 +421,11 @@ void build_widgets (Widget logSH, LogRes log_res)
 
    /*
     * Add callbacks
-    * The first three callbacks registered are for the column 1
+    */
+   XtAddCallback (form1, XmNfocusCallback, initCB,
+      (XtPointer) NULL);
+
+   /* The first three callbacks registered are for the column 1
     * pushbuttons. The date and end PB's need to know their
     * coresponding textFields, which is passed as client data.  The
     * start PB client data is a pointer to an array holding the IDs of
@@ -511,14 +513,13 @@ Widget buildOptionMenus (Widget parent, int defaultBtn, XmString *labelsXS)
    }
 
    optionForm = XtVaCreateManagedWidget ("optionForm", xmFormWidgetClass,
-      parent, NULL);
+      parent,
+      XmNborderWidth, 0,
+      NULL);
 
    i = 0;
-
-   XtSetArg (args[i], XmNnavigationType, XmTAB_GROUP);
-   i++;
-   XtSetArg (args[i], XmNentryAlignment, XmALIGNMENT_CENTER);
-   i++;
+   XtSetArg (args[i], XmNnavigationType, XmTAB_GROUP); i++;
+   XtSetArg (args[i], XmNentryAlignment, XmALIGNMENT_CENTER); i++;
 
    pulldownMenu = XmCreatePulldownMenu (optionForm, "Pulldown", args, i);
 
@@ -534,8 +535,8 @@ Widget buildOptionMenus (Widget parent, int defaultBtn, XmString *labelsXS)
          defaultWid = pulldownPB;       /* default for the option menu     */
       }
    }
-   i = 0;
 
+   i = 0;
    XtSetArg (args[i], XmNsubMenuId, pulldownMenu); i++;
    XtSetArg (args[i], XmNmenuHistory, defaultWid); i++; /* default button */
    XtSetArg (args[i], XmNtopOffset, 0); i++;
